@@ -4,6 +4,7 @@ namespace Drupal\Core\File;
 
 use Drupal\Component\FileSystem\FileSystem as FileSystemComponent;
 use Drupal\Component\Utility\Unicode;
+use Drupal\Core\DependencyInjection\DeprecatedServicePropertyTrait;
 use Drupal\Core\File\Exception\DirectoryNotReadyException;
 use Drupal\Core\File\Exception\FileException;
 use Drupal\Core\File\Exception\FileExistsException;
@@ -15,13 +16,21 @@ use Drupal\Core\Site\Settings;
 use Drupal\Core\StreamWrapper\PublicStream;
 use Drupal\Core\StreamWrapper\StreamWrapperManager;
 use Drupal\Core\StreamWrapper\StreamWrapperManagerInterface;
-use Psr\Log\LoggerInterface;
 
 /**
  * Provides helpers to operate on files and stream wrappers.
  */
 class FileSystem implements FileSystemInterface {
 
+  use DeprecatedServicePropertyTrait;
+
+  /**
+   * {@inheritdoc}
+   */
+  protected array $deprecatedProperties = [
+    'logger' => 'logger.channel.file',
+  ];
+
   /**
    * Default mode for new directories. See self::chmod().
    */
@@ -39,13 +48,6 @@ class FileSystem implements FileSystemInterface {
    */
   protected $settings;
 
-  /**
-   * The file logger channel.
-   *
-   * @var \Psr\Log\LoggerInterface
-   */
-  protected $logger;
-
   /**
    * The stream wrapper manager.
    *
@@ -60,13 +62,10 @@ class FileSystem implements FileSystemInterface {
    *   The stream wrapper manager.
    * @param \Drupal\Core\Site\Settings $settings
    *   The site settings.
-   * @param \Psr\Log\LoggerInterface $logger
-   *   The file logger channel.
    */
-  public function __construct(StreamWrapperManagerInterface $stream_wrapper_manager, Settings $settings, LoggerInterface $logger) {
+  public function __construct(StreamWrapperManagerInterface $stream_wrapper_manager, Settings $settings) {
     $this->streamWrapperManager = $stream_wrapper_manager;
     $this->settings = $settings;
-    $this->logger = $logger;
   }
 
   /**
@@ -102,19 +101,14 @@ class FileSystem implements FileSystemInterface {
       }
     }
 
-    if (@chmod($uri, $mode)) {
-      return TRUE;
-    }
-
-    $this->logger->error('The file permissions could not be set on %uri.', ['%uri' => $uri]);
-    return FALSE;
+    return @chmod($uri, $mode);
   }
 
   /**
    * {@inheritdoc}
    */
   public function unlink($uri, $context = NULL) {
-    if (!$this->streamWrapperManager->isValidUri($uri) && (substr(PHP_OS, 0, 3) == 'WIN')) {
+    if (!$this->streamWrapperManager->isValidUri($uri) && str_starts_with(PHP_OS, 'WIN')) {
       chmod($uri, 0600);
     }
     if ($context) {
@@ -214,7 +208,10 @@ class FileSystem implements FileSystemInterface {
         $recursive_path .= $component;
 
         if (!file_exists($recursive_path)) {
-          if (!$this->mkdirCall($recursive_path, $mode, FALSE, $context)) {
+          $success = $this->mkdirCall($recursive_path, $mode, FALSE, $context);
+          // If the operation failed, check again if the directory was created
+          // by another process/server, only report a failure if not.
+          if (!$success && !file_exists($recursive_path)) {
             return FALSE;
           }
           // Not necessary to use self::chmod() as there is no scheme.
@@ -237,8 +234,7 @@ class FileSystem implements FileSystemInterface {
   }
 
   /**
-   * Helper function. Ensures we don't pass a NULL as a context resource to
-   * mkdir().
+   * Ensures we don't pass a NULL as a context resource to mkdir().
    *
    * @see self::mkdir()
    */
@@ -255,7 +251,7 @@ class FileSystem implements FileSystemInterface {
    * {@inheritdoc}
    */
   public function rmdir($uri, $context = NULL) {
-    if (!$this->streamWrapperManager->isValidUri($uri) && (substr(PHP_OS, 0, 3) == 'WIN')) {
+    if (!$this->streamWrapperManager->isValidUri($uri) && str_starts_with(PHP_OS, 'WIN')) {
       chmod($uri, 0700);
     }
     if ($context) {
@@ -291,8 +287,12 @@ class FileSystem implements FileSystemInterface {
   /**
    * {@inheritdoc}
    */
-  public function copy($source, $destination, $replace = self::EXISTS_RENAME) {
-    $this->prepareDestination($source, $destination, $replace);
+  public function copy($source, $destination, /* FileExists */$fileExists = FileExists::Rename) {
+    if (!$fileExists instanceof FileExists) {
+      // @phpstan-ignore staticMethod.deprecated
+      $fileExists = FileExists::fromLegacyInt($fileExists, __METHOD__);
+    }
+    $this->prepareDestination($source, $destination, $fileExists);
 
     if (!@copy($source, $destination)) {
       // If the copy failed and realpaths exist, retry the operation using them
@@ -300,10 +300,6 @@ class FileSystem implements FileSystemInterface {
       $real_source = $this->realpath($source) ?: $source;
       $real_destination = $this->realpath($destination) ?: $destination;
       if ($real_source === FALSE || $real_destination === FALSE || !@copy($real_source, $real_destination)) {
-        $this->logger->error("The specified file '%source' could not be copied to '%destination'.", [
-          '%source' => $source,
-          '%destination' => $destination,
-        ]);
         throw new FileWriteException("The specified file '$source' could not be copied to '$destination'.");
       }
     }
@@ -320,38 +316,38 @@ class FileSystem implements FileSystemInterface {
   public function delete($path) {
     if (is_file($path)) {
       if (!$this->unlink($path)) {
-        $this->logger->error("Failed to unlink file '%path'.", ['%path' => $path]);
         throw new FileException("Failed to unlink file '$path'.");
       }
       return TRUE;
     }
 
     if (is_dir($path)) {
-      $this->logger->error("Cannot delete '%path' because it is a directory. Use deleteRecursive() instead.", ['%path' => $path]);
       throw new NotRegularFileException("Cannot delete '$path' because it is a directory. Use deleteRecursive() instead.");
     }
 
-    // Return TRUE for non-existent file, but log that nothing was actually
-    // deleted, as the current state is the intended result.
+    // Return TRUE for non-existent file as the current state is the intended
+    // result.
     if (!file_exists($path)) {
-      $this->logger->notice('The file %path was not deleted because it does not exist.', ['%path' => $path]);
       return TRUE;
     }
 
     // We cannot handle anything other than files and directories.
     // Throw an exception for everything else (sockets, symbolic links, etc).
-    $this->logger->error("The file '%path' is not of a recognized type so it was not deleted.", ['%path' => $path]);
     throw new NotRegularFileException("The file '$path' is not of a recognized type so it was not deleted.");
   }
 
   /**
    * {@inheritdoc}
    */
-  public function deleteRecursive($path, callable $callback = NULL) {
+  public function deleteRecursive($path, ?callable $callback = NULL) {
     if ($callback) {
       call_user_func($callback, $path);
     }
 
+    if (!file_exists($path)) {
+      return TRUE;
+    }
+
     if (is_dir($path)) {
       $dir = dir($path);
       while (($entry = $dir->read()) !== FALSE) {
@@ -372,12 +368,16 @@ class FileSystem implements FileSystemInterface {
   /**
    * {@inheritdoc}
    */
-  public function move($source, $destination, $replace = self::EXISTS_RENAME) {
-    $this->prepareDestination($source, $destination, $replace);
+  public function move($source, $destination, /* FileExists */$fileExists = FileExists::Rename) {
+    if (!$fileExists instanceof FileExists) {
+      // @phpstan-ignore staticMethod.deprecated
+      $fileExists = FileExists::fromLegacyInt($fileExists, __METHOD__);
+    }
+    $this->prepareDestination($source, $destination, $fileExists);
 
     // Ensure compatibility with Windows.
     // @see \Drupal\Core\File\FileSystemInterface::unlink().
-    if (!$this->streamWrapperManager->isValidUri($source) && (substr(PHP_OS, 0, 3) == 'WIN')) {
+    if (!$this->streamWrapperManager->isValidUri($source) && str_starts_with(PHP_OS, 'WIN')) {
       chmod($source, 0600);
     }
     // Attempt to resolve the URIs. This is necessary in certain
@@ -392,17 +392,9 @@ class FileSystem implements FileSystemInterface {
       // been implemented. It's not necessary to use FileSystem::unlink() as the
       // Windows issue has already been resolved above.
       if (!@copy($real_source, $real_destination)) {
-        $this->logger->error("The specified file '%source' could not be moved to '%destination'.", [
-          '%source' => $source,
-          '%destination' => $destination,
-        ]);
         throw new FileWriteException("The specified file '$source' could not be moved to '$destination'.");
       }
       if (!@unlink($real_source)) {
-        $this->logger->error("The source file '%source' could not be unlinked after copying to '%destination'.", [
-          '%source' => $source,
-          '%destination' => $destination,
-        ]);
         throw new FileException("The source file '$source' could not be unlinked after copying to '$destination'.");
       }
     }
@@ -428,31 +420,27 @@ class FileSystem implements FileSystemInterface {
    *   A URI containing the destination that $source should be moved/copied to.
    *   The URI may be a bare filepath (without a scheme) and in that case the
    *   default scheme (file://) will be used.
-   * @param int $replace
-   *   Replace behavior when the destination file already exists:
-   *   - FileSystemInterface::EXISTS_REPLACE - Replace the existing file.
-   *   - FileSystemInterface::EXISTS_RENAME - Append _{incrementing number}
-   *     until the filename is unique.
-   *   - FileSystemInterface::EXISTS_ERROR - Do nothing and return FALSE.
+   * @param \Drupal\Core\File\FileExists|int $fileExists
+   *   Replace behavior when the destination file already exists.
+   *
+   * @throws \TypeError
+   *   Thrown when the $fileExists parameter is not an enum or legacy int.
    *
    * @see \Drupal\Core\File\FileSystemInterface::copy()
    * @see \Drupal\Core\File\FileSystemInterface::move()
    */
-  protected function prepareDestination($source, &$destination, $replace) {
+  protected function prepareDestination($source, &$destination, /* FileExists */$fileExists) {
+    if (!$fileExists instanceof FileExists) {
+      // @phpstan-ignore staticMethod.deprecated
+      $fileExists = FileExists::fromLegacyInt($fileExists, __METHOD__);
+    }
     $original_source = $source;
 
     if (!file_exists($source)) {
       if (($realpath = $this->realpath($original_source)) !== FALSE) {
-        $this->logger->error("File '%original_source' ('%realpath') could not be copied because it does not exist.", [
-          '%original_source' => $original_source,
-          '%realpath' => $realpath,
-        ]);
         throw new FileNotExistsException("File '$original_source' ('$realpath') could not be copied because it does not exist.");
       }
       else {
-        $this->logger->error("File '%original_source' could not be copied because it does not exist.", [
-          '%original_source' => $original_source,
-        ]);
         throw new FileNotExistsException("File '$original_source' could not be copied because it does not exist.");
       }
     }
@@ -466,20 +454,13 @@ class FileSystem implements FileSystemInterface {
       // Perhaps $destination is a dir/file?
       $dirname = $this->dirname($destination);
       if (!$this->prepareDirectory($dirname)) {
-        $this->logger->error("The specified file '%original_source' could not be copied because the destination directory is not properly configured. This may be caused by a problem with file or directory permissions.", [
-          '%original_source' => $original_source,
-        ]);
-        throw new DirectoryNotReadyException("The specified file '$original_source' could not be copied because the destination directory is not properly configured. This may be caused by a problem with file or directory permissions.");
+        throw new DirectoryNotReadyException("The specified file '$original_source' could not be copied because the destination directory '$dirname' is not properly configured. This may be caused by a problem with file or directory permissions.");
       }
     }
 
     // Determine whether we can perform this operation based on overwrite rules.
-    $destination = $this->getDestinationFilename($destination, $replace);
+    $destination = $this->getDestinationFilename($destination, $fileExists);
     if ($destination === FALSE) {
-      $this->logger->error("File '%original_source' could not be copied because a file by that name already exists in the destination directory ('%destination').", [
-        '%original_source' => $original_source,
-        '%destination' => $destination,
-      ]);
       throw new FileExistsException("File '$original_source' could not be copied because a file by that name already exists in the destination directory ('$destination').");
     }
 
@@ -487,9 +468,6 @@ class FileSystem implements FileSystemInterface {
     $real_source = $this->realpath($source);
     $real_destination = $this->realpath($destination);
     if ($source == $destination || ($real_source !== FALSE) && ($real_source == $real_destination)) {
-      $this->logger->error("File '%source' could not be copied because it would overwrite itself.", [
-        '%source' => $source,
-      ]);
       throw new FileException("File '$source' could not be copied because it would overwrite itself.");
     }
   }
@@ -497,16 +475,19 @@ class FileSystem implements FileSystemInterface {
   /**
    * {@inheritdoc}
    */
-  public function saveData($data, $destination, $replace = self::EXISTS_RENAME) {
+  public function saveData($data, $destination, /* FileExists */$fileExists = FileExists::Rename) {
+    if (!$fileExists instanceof FileExists) {
+      // @phpstan-ignore staticMethod.deprecated
+      $fileExists = FileExists::fromLegacyInt($fileExists, __METHOD__);
+    }
     // Write the data to a temporary file.
     $temp_name = $this->tempnam('temporary://', 'file');
     if (file_put_contents($temp_name, $data) === FALSE) {
-      $this->logger->error("Temporary file '%temp_name' could not be created.", ['%temp_name' => $temp_name]);
       throw new FileWriteException("Temporary file '$temp_name' could not be created.");
     }
 
     // Move the file to its final destination.
-    return $this->move($temp_name, $destination, $replace);
+    return $this->move($temp_name, $destination, $fileExists);
   }
 
   /**
@@ -519,12 +500,22 @@ class FileSystem implements FileSystemInterface {
     }
 
     if (!is_dir($directory)) {
+      if (!($options & static::CREATE_DIRECTORY)) {
+        return FALSE;
+      }
+
       // Let mkdir() recursively create directories and use the default
       // directory permissions.
-      if ($options & static::CREATE_DIRECTORY) {
-        return @$this->mkdir($directory, NULL, TRUE);
+      $success = @$this->mkdir($directory, NULL, TRUE);
+      if ($success) {
+        return TRUE;
+      }
+      // If the operation failed, check again if the directory was created
+      // by another process/server, only report a failure if not. In this case
+      // we still need to ensure the directory is writable.
+      if (!is_dir($directory)) {
+        return FALSE;
       }
-      return FALSE;
     }
 
     $writable = is_writable($directory);
@@ -538,23 +529,27 @@ class FileSystem implements FileSystemInterface {
   /**
    * {@inheritdoc}
    */
-  public function getDestinationFilename($destination, $replace) {
+  public function getDestinationFilename($destination, /* FileExists */$fileExists) {
+    if (!$fileExists instanceof FileExists) {
+      // @phpstan-ignore staticMethod.deprecated
+      $fileExists = FileExists::fromLegacyInt($fileExists, __METHOD__);
+    }
     $basename = $this->basename($destination);
     if (!Unicode::validateUtf8($basename)) {
       throw new FileException(sprintf("Invalid filename '%s'", $basename));
     }
     if (file_exists($destination)) {
-      switch ($replace) {
-        case FileSystemInterface::EXISTS_REPLACE:
+      switch ($fileExists) {
+        case FileExists::Replace:
           // Do nothing here, we want to overwrite the existing file.
           break;
 
-        case FileSystemInterface::EXISTS_RENAME:
+        case FileExists::Rename:
           $directory = $this->dirname($destination);
           $destination = $this->createFilename($basename, $directory);
           break;
 
-        case FileSystemInterface::EXISTS_ERROR:
+        case FileExists::Error:
           // Error reporting handled by calling function.
           return FALSE;
       }
@@ -573,13 +568,13 @@ class FileSystem implements FileSystemInterface {
     if (preg_last_error() !== PREG_NO_ERROR) {
       throw new FileException(sprintf("Invalid filename '%s'", $original));
     }
-    if (substr(PHP_OS, 0, 3) == 'WIN') {
+    if (str_starts_with(PHP_OS, 'WIN')) {
       // These characters are not allowed in Windows filenames.
       $basename = str_replace([':', '*', '?', '"', '<', '>', '|'], '_', $basename);
     }
 
     // A URI or path may already have a trailing slash or look like "public://".
-    if (substr($directory, -1) == '/') {
+    if (str_ends_with($directory, '/')) {
       $separator = '';
     }
     else {
@@ -686,33 +681,32 @@ class FileSystem implements FileSystemInterface {
    * @see \Drupal\Core\File\FileSystemInterface::scanDirectory()
    */
   protected function doScanDirectory($dir, $mask, array $options = [], $depth = 0) {
-    $files = [];
+    $files_in_sub_dirs = [];
+    $files_in_this_directory = [];
     // Avoid warnings when opendir does not have the permissions to open a
     // directory.
     if ($handle = @opendir($dir)) {
       while (FALSE !== ($filename = readdir($handle))) {
         // Skip this file if it matches the nomask or starts with a dot.
         if ($filename[0] != '.' && !(preg_match($options['nomask'], $filename))) {
-          if (substr($dir, -1) == '/') {
+          if (str_ends_with($dir, '/')) {
             $uri = "$dir$filename";
           }
           else {
             $uri = "$dir/$filename";
           }
           if ($options['recurse'] && is_dir($uri)) {
-            // Give priority to files in this folder by merging them in after
-            // any subdirectory files.
-            $files = array_merge($this->doScanDirectory($uri, $mask, $options, $depth + 1), $files);
+            $files_in_sub_dirs[] = $this->doScanDirectory($uri, $mask, $options, $depth + 1);
           }
           elseif ($depth >= $options['min_depth'] && preg_match($mask, $filename)) {
-            // Always use this match over anything already set in $files with
-            // the same $options['key'].
+            // Always use this match over anything already set with the same
+            // $options['key'].
             $file = new \stdClass();
             $file->uri = $uri;
             $file->filename = $filename;
             $file->name = pathinfo($filename, PATHINFO_FILENAME);
             $key = $options['key'];
-            $files[$file->$key] = $file;
+            $files_in_this_directory[$file->$key] = $file;
             if ($options['callback']) {
               $options['callback']($uri);
             }
@@ -721,11 +715,10 @@ class FileSystem implements FileSystemInterface {
       }
       closedir($handle);
     }
-    else {
-      $this->logger->error('@dir can not be opened', ['@dir' => $dir]);
-    }
 
-    return $files;
+    // Give priority to files in this folder by merging them after
+    // any subdirectory files.
+    return array_merge(array_merge(...$files_in_sub_dirs), $files_in_this_directory);
   }
 
 }
