@@ -1,7 +1,10 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\config\Functional;
 
+use Drupal\Component\Utility\Html;
 use Drupal\Tests\BrowserTestBase;
 use Drupal\user\Entity\Role;
 
@@ -23,9 +26,9 @@ class ConfigDraggableListBuilderTest extends BrowserTestBase {
   protected $defaultTheme = 'stark';
 
   /**
-   * Test draggable lists.
+   * Tests draggable lists.
    */
-  public function testDraggableList() {
+  public function testDraggableList(): void {
     $this->drupalLogin($this->drupalCreateUser(['administer permissions']));
 
     // Create more than 50 roles.
@@ -49,6 +52,13 @@ class ConfigDraggableListBuilderTest extends BrowserTestBase {
     for ($i = 0; $i < 51; $i++) {
       $this->assertSession()->pageTextContains("Role $i");
     }
+
+    $role = Role::load('role_0');
+    $role_name = 'Role <b>0</b>';
+    $role->set('label', $role_name)->save();
+
+    $this->drupalGet('admin/people/roles');
+    $this->assertSession()->responseContains('<td>' . Html::escape($role_name));
   }
 
 }
