@@ -1,7 +1,10 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\file\Kernel;
 
+use Drupal\Core\Entity\EntityInterface;
 use Drupal\file\Entity\File;
 use Drupal\file\FileInterface;
 
@@ -44,7 +47,7 @@ class SpaceUsedTest extends FileManagedUnitTestBase {
    * @return \Drupal\Core\Entity\EntityInterface
    *   The file entity.
    */
-  protected function createFileWithSize($uri, $size, $uid, $status = FileInterface::STATUS_PERMANENT) {
+  protected function createFileWithSize($uri, $size, $uid, $status = FileInterface::STATUS_PERMANENT): EntityInterface {
     file_put_contents($uri, $this->randomMachineName($size));
     $file = File::create([
       'uri' => $uri,
@@ -58,7 +61,7 @@ class SpaceUsedTest extends FileManagedUnitTestBase {
   /**
    * Tests different users with the default status.
    */
-  public function testFileSpaceUsed() {
+  public function testFileSpaceUsed(): void {
     $file = $this->container->get('entity_type.manager')->getStorage('file');
     // Test different users with default status.
     $this->assertEquals(70, $file->spaceUsed(2));
