@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\filter\Functional;
 
 use Drupal\Core\Access\AccessResult;
@@ -17,9 +19,7 @@ use Drupal\user\RoleInterface;
 class FilterFormatAccessTest extends BrowserTestBase {
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = ['block', 'filter', 'node'];
 
@@ -75,9 +75,6 @@ class FilterFormatAccessTest extends BrowserTestBase {
    */
   protected function setUp(): void {
     parent::setUp();
-
-    $this->drupalPlaceBlock('page_title_block');
-
     $this->drupalCreateContentType(['type' => 'page', 'name' => 'Basic page']);
 
     // Create a user who can administer text formats, but does not have
@@ -90,20 +87,16 @@ class FilterFormatAccessTest extends BrowserTestBase {
 
     // Create three text formats. Two text formats are created for all users so
     // that the drop-down list appears for all tests.
-    $this->drupalLogin($this->filterAdminUser);
     $formats = [];
     for ($i = 0; $i < 3; $i++) {
-      $edit = [
+      $format = FilterFormat::create([
         'format' => $this->randomMachineName(),
         'name' => $this->randomMachineName(),
-      ];
-      $this->drupalGet('admin/config/content/formats/add');
-      $this->submitForm($edit, 'Save configuration');
-      $this->resetFilterCaches();
-      $formats[] = FilterFormat::load($edit['format']);
+      ]);
+      $format->save();
+      $formats[] = $format;
     }
     [$this->allowedFormat, $this->secondAllowedFormat, $this->disallowedFormat] = $formats;
-    $this->drupalLogout();
 
     // Create a regular user with access to two of the formats.
     $this->webUser = $this->drupalCreateUser([
@@ -128,7 +121,7 @@ class FilterFormatAccessTest extends BrowserTestBase {
   /**
    * Tests the Filter format access permissions functionality.
    */
-  public function testFormatPermissions() {
+  public function testFormatPermissions(): void {
     // Make sure that a regular user only has access to the text formats for
     // which they were granted access.
     $fallback_format = FilterFormat::load(filter_fallback_format());
@@ -184,7 +177,7 @@ class FilterFormatAccessTest extends BrowserTestBase {
   /**
    * Tests if text format is available to a role.
    */
-  public function testFormatRoles() {
+  public function testFormatRoles(): void {
     // Get the role ID assigned to the regular user.
     $roles = $this->webUser->getRoles(TRUE);
     $rid = $roles[0];
@@ -216,7 +209,7 @@ class FilterFormatAccessTest extends BrowserTestBase {
    * be edited by administrators only, but that the administrator is forced to
    * choose a new format before saving the page.
    */
-  public function testFormatWidgetPermissions() {
+  public function testFormatWidgetPermissions(): void {
     $body_value_key = 'body[0][value]';
     $body_format_key = 'body[0][format]';
 
@@ -342,7 +335,7 @@ class FilterFormatAccessTest extends BrowserTestBase {
   /**
    * Rebuilds text format and permission caches in the thread running the tests.
    */
-  protected function resetFilterCaches() {
+  protected function resetFilterCaches(): void {
     filter_formats_reset();
   }
 
