@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\image\Kernel;
 
 use Drupal\image\Entity\ImageStyle;
@@ -20,14 +22,14 @@ class ImageImportTest extends KernelTestBase {
   /**
    * Tests importing image styles.
    */
-  public function testImport() {
+  public function testImport(): void {
     $style = ImageStyle::create([
       'name' => 'test',
       'label' => 'Test',
     ]);
 
-    $style->addImageEffect(['id' => 'image_module_test_null']);
-    $style->addImageEffect(['id' => 'image_module_test_null']);
+    $style->addImageEffect(['id' => 'image_module_test_null', 'weight' => 0]);
+    $style->addImageEffect(['id' => 'image_module_test_null', 'weight' => 1]);
     $style->save();
 
     $this->assertCount(2, $style->getEffects());
@@ -36,6 +38,7 @@ class ImageImportTest extends KernelTestBase {
     $style->set('effects', [
       $uuid => [
         'id' => 'image_module_test_null',
+        'weight' => 0,
       ],
     ]);
     $style->save();
