@@ -24,6 +24,7 @@ use Symfony\Component\Routing\RouteCollection;
  * @coversDefaultClass \Drupal\layout_builder\Plugin\SectionStorage\OverridesSectionStorage
  *
  * @group layout_builder
+ * @group #slow
  */
 class OverridesSectionStorageTest extends UnitTestCase {
 
@@ -88,7 +89,7 @@ class OverridesSectionStorageTest extends UnitTestCase {
    * @param array $defaults
    *   The defaults to pass to ::extractEntityFromRoute().
    */
-  public function testExtractEntityFromRoute($success, $expected_entity_type_id, $value, array $defaults) {
+  public function testExtractEntityFromRoute($success, $expected_entity_type_id, $value, array $defaults): void {
     if ($expected_entity_type_id) {
       $entity_without_layout = $this->prophesize(FieldableEntityInterface::class);
       $entity_without_layout->hasField(OverridesSectionStorage::FIELD_NAME)->willReturn(FALSE);
@@ -120,7 +121,7 @@ class OverridesSectionStorageTest extends UnitTestCase {
   /**
    * Provides data for ::testExtractEntityFromRoute().
    */
-  public function providerTestExtractEntityFromRoute() {
+  public static function providerTestExtractEntityFromRoute() {
     // Data provider values are:
     // - whether a successful result is expected
     // - the expected entity ID
@@ -163,7 +164,7 @@ class OverridesSectionStorageTest extends UnitTestCase {
    * @covers ::getEntityTypes
    * @covers \Drupal\layout_builder\Routing\LayoutBuilderRoutesTrait::buildLayoutRoutes
    */
-  public function testBuildRoutes() {
+  public function testBuildRoutes(): void {
     $entity_types = [];
 
     $not_fieldable = $this->prophesize(EntityTypeInterface::class);
@@ -272,6 +273,7 @@ class OverridesSectionStorageTest extends UnitTestCase {
             'from_canonical' => ['type' => 'entity:from_canonical'],
           ],
           '_layout_builder' => TRUE,
+          '_admin_route' => FALSE,
         ]
       ),
       'layout_builder.overrides.from_canonical.discard_changes' => new Route(
@@ -292,6 +294,7 @@ class OverridesSectionStorageTest extends UnitTestCase {
             'from_canonical' => ['type' => 'entity:from_canonical'],
           ],
           '_layout_builder' => TRUE,
+          '_admin_route' => FALSE,
         ]
       ),
       'layout_builder.overrides.from_canonical.revert' => new Route(
@@ -312,6 +315,7 @@ class OverridesSectionStorageTest extends UnitTestCase {
             'from_canonical' => ['type' => 'entity:from_canonical'],
           ],
           '_layout_builder' => TRUE,
+          '_admin_route' => FALSE,
         ]
       ),
       'layout_builder.overrides.with_string_id.view' => new Route(
@@ -332,6 +336,7 @@ class OverridesSectionStorageTest extends UnitTestCase {
             'with_string_id' => ['type' => 'entity:with_string_id'],
           ],
           '_layout_builder' => TRUE,
+          '_admin_route' => FALSE,
         ]
       ),
       'layout_builder.overrides.with_string_id.discard_changes' => new Route(
@@ -351,6 +356,7 @@ class OverridesSectionStorageTest extends UnitTestCase {
             'with_string_id' => ['type' => 'entity:with_string_id'],
           ],
           '_layout_builder' => TRUE,
+          '_admin_route' => FALSE,
         ]
       ),
       'layout_builder.overrides.with_string_id.revert' => new Route(
@@ -370,6 +376,7 @@ class OverridesSectionStorageTest extends UnitTestCase {
             'with_string_id' => ['type' => 'entity:with_string_id'],
           ],
           '_layout_builder' => TRUE,
+          '_admin_route' => FALSE,
         ]
       ),
       'layout_builder.overrides.with_integer_id.view' => new Route(
@@ -391,6 +398,7 @@ class OverridesSectionStorageTest extends UnitTestCase {
             'with_integer_id' => ['type' => 'entity:with_integer_id'],
           ],
           '_layout_builder' => TRUE,
+          '_admin_route' => FALSE,
         ]
       ),
       'layout_builder.overrides.with_integer_id.discard_changes' => new Route(
@@ -411,6 +419,7 @@ class OverridesSectionStorageTest extends UnitTestCase {
             'with_integer_id' => ['type' => 'entity:with_integer_id'],
           ],
           '_layout_builder' => TRUE,
+          '_admin_route' => FALSE,
         ]
       ),
       'layout_builder.overrides.with_integer_id.revert' => new Route(
@@ -431,6 +440,7 @@ class OverridesSectionStorageTest extends UnitTestCase {
             'with_integer_id' => ['type' => 'entity:with_integer_id'],
           ],
           '_layout_builder' => TRUE,
+          '_admin_route' => FALSE,
         ]
       ),
     ];
