@@ -1,8 +1,11 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\migrate_drupal_ui\Functional;
 
 use Drupal\Core\Entity\ContentEntityStorageInterface;
+use Drupal\Core\Logger\RfcLogLevel;
 use Drupal\Tests\migrate_drupal\Traits\CreateTestContentEntitiesTrait;
 
 /**
@@ -12,6 +15,27 @@ abstract class MigrateUpgradeExecuteTestBase extends MigrateUpgradeTestBase {
 
   use CreateTestContentEntitiesTrait;
 
+  /**
+   * Indicates if the watchdog logs should be output.
+   *
+   * @var bool
+   */
+  protected bool $outputLogs = FALSE;
+
+  /**
+   * The admin username after the migration.
+   *
+   * @var string
+   */
+  protected string $migratedAdminUserName = 'admin';
+
+  /**
+   * The number of expected logged errors of type migrate_drupal_ui.
+   *
+   * @var int
+   */
+  protected int $expectedLoggedErrors = 0;
+
   /**
    * {@inheritdoc}
    */
@@ -23,6 +47,16 @@ abstract class MigrateUpgradeExecuteTestBase extends MigrateUpgradeTestBase {
 
   }
 
+  /**
+   * {@inheritdoc}
+   */
+  protected function tearDown(): void {
+    if ($this->outputLogs) {
+      $this->outputLogs($this->migratedAdminUserName);
+    }
+    parent::tearDown();
+  }
+
   /**
    * Executes an upgrade and then an incremental upgrade.
    */
@@ -108,4 +142,35 @@ abstract class MigrateUpgradeExecuteTestBase extends MigrateUpgradeTestBase {
     );
   }
 
+  /**
+   * Asserts log errors.
+   */
+  public function assertLogError(): void {
+    $db = \Drupal::service('database');
+    $num_errors = $db->select('watchdog', 'w')
+      ->fields('w')
+      ->condition('type', 'migrate_drupal_ui')
+      ->condition('severity', RfcLogLevel::ERROR)
+      ->countQuery()
+      ->execute()
+      ->fetchField();
+    $this->assertSame($this->expectedLoggedErrors, (int) $num_errors);
+  }
+
+  /**
+   * Preserve the logs pages.
+   */
+  public function outputLogs(string $username): void {
+    // Ensure user 1 is accessing the admin log. Change the username because
+    // the migration changes the username of user 1 but not the password.
+    if (\Drupal::currentUser()->id() != 1) {
+      $this->rootUser->name = $username;
+      $this->drupalLogin($this->rootUser);
+    }
+    $this->drupalGet('/admin/reports/dblog');
+    while ($next_link = $this->getSession()->getPage()->findLink('Next page')) {
+      $next_link->click();
+    }
+  }
+
 }
