@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\shortcut\Kernel\Migrate\d7;
 
 use Drupal\user\Entity\User;
@@ -13,9 +15,7 @@ use Drupal\Tests\migrate_drupal\Kernel\d7\MigrateDrupal7TestBase;
 class MigrateShortcutSetUsersTest extends MigrateDrupal7TestBase {
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = [
     'link',
@@ -42,10 +42,11 @@ class MigrateShortcutSetUsersTest extends MigrateDrupal7TestBase {
   /**
    * Tests the shortcut set migration.
    */
-  public function testShortcutSetUsersMigration() {
+  public function testShortcutSetUsersMigration(): void {
     // Check if migrated user has correct migrated shortcut set assigned.
     $account = User::load(2);
-    $shortcut_set = shortcut_current_displayed_set($account);
+    $shortcut_set_storage = \Drupal::entityTypeManager()->getStorage('shortcut_set');
+    $shortcut_set = $shortcut_set_storage->getDisplayedToUser($account);
     /** @var \Drupal\shortcut\ShortcutSetInterface $shortcut_set */
     $this->assertSame('shortcut-set-2', $shortcut_set->id());
   }
