@@ -1,8 +1,11 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\accept_header_routing_test;
 
 use Symfony\Component\HttpFoundation\Request;
+use Symfony\Component\HttpFoundation\Response;
 use Symfony\Component\HttpKernel\HttpKernelInterface;
 
 /**
@@ -10,6 +13,11 @@ use Symfony\Component\HttpKernel\HttpKernelInterface;
  */
 class AcceptHeaderMiddleware implements HttpKernelInterface {
 
+  /**
+   * The app kernel.
+   */
+  protected HttpKernelInterface $app;
+
   /**
    * Constructs a new AcceptHeaderMiddleware instance.
    *
@@ -23,10 +31,9 @@ class AcceptHeaderMiddleware implements HttpKernelInterface {
   /**
    * {@inheritdoc}
    */
-  public function handle(Request $request, $type = self::MASTER_REQUEST, $catch = TRUE) {
+  public function handle(Request $request, $type = self::MAIN_REQUEST, $catch = TRUE): Response {
     $mapping = [
       'application/json' => 'json',
-      'application/hal+json' => 'hal_json',
       'application/xml' => 'xml',
       'text/html' => 'html',
     ];
