@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\KernelTests\Core\Entity;
 
 use Drupal\Component\Plugin\Exception\PluginNotFoundException;
@@ -16,7 +18,6 @@ use Drupal\Core\Language\LanguageInterface;
 use Drupal\Core\StringTranslation\TranslatableMarkup;
 use Drupal\entity_test\FieldStorageDefinition;
 use Drupal\entity_test_update\Entity\EntityTestUpdate;
-use Drupal\language\Entity\ConfigurableLanguage;
 use Drupal\Tests\system\Functional\Entity\Traits\EntityDefinitionTestTrait;
 
 /**
@@ -53,9 +54,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
   protected $database;
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = ['entity_test_update', 'language'];
 
@@ -78,7 +77,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
   /**
    * Tests that new entity type definitions are correctly handled.
    */
-  public function testNewEntityType() {
+  public function testNewEntityType(): void {
     $entity_type_id = 'entity_test_new';
     $schema = $this->database->schema();
 
@@ -98,7 +97,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
   /**
    * Tests when no definition update is needed.
    */
-  public function testNoUpdates() {
+  public function testNoUpdates(): void {
     // Ensure that the definition update manager reports no updates.
     $this->assertFalse($this->entityDefinitionUpdateManager->needsUpdates(), 'EntityDefinitionUpdateManager reports that no updates are needed.');
     $this->assertSame([], $this->entityDefinitionUpdateManager->getChangeSummary(), 'EntityDefinitionUpdateManager reports an empty change summary.');
@@ -108,7 +107,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
   /**
    * Tests updating entity schema when there are no existing entities.
    */
-  public function testEntityTypeUpdateWithoutData() {
+  public function testEntityTypeUpdateWithoutData(): void {
     // The 'entity_test_update' entity type starts out non-revisionable, so
     // ensure the revision table hasn't been created during setUp().
     $this->assertFalse($this->database->schema()->tableExists('entity_test_update_revision'), 'Revision table not created for entity_test_update.');
@@ -136,7 +135,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
   /**
    * Tests updating entity schema when there are entity storage changes.
    */
-  public function testEntityTypeUpdateWithEntityStorageChange() {
+  public function testEntityTypeUpdateWithEntityStorageChange(): void {
     // Update the entity type to be revisionable and try to apply the update.
     // It's expected to throw an exception.
     $entity_type = $this->getUpdatedEntityTypeDefinition(TRUE, FALSE);
@@ -144,7 +143,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
       $this->entityDefinitionUpdateManager->updateEntityType($entity_type);
       $this->fail('EntityStorageException thrown when trying to apply an update that requires shared table schema changes.');
     }
-    catch (EntityStorageException $e) {
+    catch (EntityStorageException) {
       // Expected exception; just continue testing.
     }
   }
@@ -154,7 +153,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
    *
    * @covers ::installFieldableEntityType
    */
-  public function testInstallAdditionalBaseFieldDuringFieldableEntityTypeInstallation() {
+  public function testInstallAdditionalBaseFieldDuringFieldableEntityTypeInstallation(): void {
     $entity_type = clone $this->entityTypeManager->getDefinition('entity_test_update');
     $field_storage_definitions = \Drupal::service('entity_field.manager')->getFieldStorageDefinitions('entity_test_update');
 
@@ -176,7 +175,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
    *
    * @covers ::installFieldableEntityType
    */
-  public function testInstallFieldableEntityTypeWithoutInCodeDefinition() {
+  public function testInstallFieldableEntityTypeWithoutInCodeDefinition(): void {
     $entity_type = clone $this->entityTypeManager->getDefinition('entity_test_update');
     $field_storage_definitions = \Drupal::service('entity_field.manager')->getFieldStorageDefinitions('entity_test_update');
 
@@ -194,7 +193,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
    *
    * @covers ::updateEntityType
    */
-  public function testUpdateEntityTypeWithoutInCodeDefinition() {
+  public function testUpdateEntityTypeWithoutInCodeDefinition(): void {
     $entity_type = clone $this->entityTypeManager->getDefinition('entity_test_update');
 
     // Remove the entity type definition. This is the same thing as removing the
@@ -214,7 +213,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
    *
    * @covers ::updateFieldableEntityType
    */
-  public function testUpdateFieldableEntityTypeWithoutInCodeDefinition() {
+  public function testUpdateFieldableEntityTypeWithoutInCodeDefinition(): void {
     $entity_type = clone $this->entityTypeManager->getDefinition('entity_test_update');
     $field_storage_definitions = \Drupal::service('entity_field.manager')->getFieldStorageDefinitions('entity_test_update');
 
@@ -236,7 +235,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
    *
    * @covers ::uninstallEntityType
    */
-  public function testUninstallEntityTypeWithoutInCodeDefinition() {
+  public function testUninstallEntityTypeWithoutInCodeDefinition(): void {
     $entity_type = clone $this->entityTypeManager->getDefinition('entity_test_update');
 
     // Remove the entity type definition. This is the same thing as removing the
@@ -254,7 +253,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
    *
    * @covers ::uninstallEntityType
    */
-  public function testUninstallRevisionableEntityTypeWithoutInCodeDefinition() {
+  public function testUninstallRevisionableEntityTypeWithoutInCodeDefinition(): void {
     $this->updateEntityTypeToRevisionable(TRUE);
     $entity_type = $this->entityDefinitionUpdateManager->getEntityType('entity_test_update');
 
@@ -271,7 +270,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
   /**
    * Tests creating, updating, and deleting a base field if no entities exist.
    */
-  public function testBaseFieldCreateUpdateDeleteWithoutData() {
+  public function testBaseFieldCreateUpdateDeleteWithoutData(): void {
     // Add a base field, ensure the update manager reports it, and the update
     // creates its schema.
     $this->addBaseField();
@@ -332,7 +331,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
    *
    * See testBaseFieldCreateUpdateDeleteWithoutData() for more details
    */
-  public function testBaseFieldWithoutLabelCreateUpdateDelete() {
+  public function testBaseFieldWithoutLabelCreateUpdateDelete(): void {
     // Add a base field, ensure the update manager reports it with the
     // field id.
     $this->addBaseField('string', 'entity_test_update', FALSE, FALSE);
@@ -360,7 +359,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
   /**
    * Tests creating, updating, and deleting a bundle field if no entities exist.
    */
-  public function testBundleFieldCreateUpdateDeleteWithoutData() {
+  public function testBundleFieldCreateUpdateDeleteWithoutData(): void {
     // Add a bundle field, ensure the update manager reports it, and the update
     // creates its schema.
     $this->addBundleField();
@@ -401,7 +400,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
    *
    * @see testBaseFieldDeleteWithExistingData()
    */
-  public function testBaseFieldCreateDeleteWithExistingEntities() {
+  public function testBaseFieldCreateDeleteWithExistingEntities(): void {
     // Save an entity.
     $name = $this->randomString();
     $storage = $this->entityTypeManager->getStorage('entity_test_update');
@@ -457,7 +456,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
    *
    * @see testBundleFieldDeleteWithExistingData()
    */
-  public function testBundleFieldCreateDeleteWithExistingEntities() {
+  public function testBundleFieldCreateDeleteWithExistingEntities(): void {
     // Save an entity.
     $name = $this->randomString();
     $storage = $this->entityTypeManager->getStorage('entity_test_update');
@@ -502,7 +501,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
         ->execute();
       $this->fail($message);
     }
-    catch (IntegrityConstraintViolationException $e) {
+    catch (IntegrityConstraintViolationException) {
       // Now provide a value for the 'not null' column. This is expected to
       // succeed.
       $values['new_bundle_field_shape'] = $this->randomString();
@@ -512,232 +511,10 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
     }
   }
 
-  /**
-   * Tests deleting a base field when it has existing data.
-   *
-   * @dataProvider baseFieldDeleteWithExistingDataTestCases
-   */
-  public function testBaseFieldDeleteWithExistingData($entity_type_id, $create_entity_revision, $base_field_revisionable, $create_entity_translation) {
-    // Enable an additional language.
-    ConfigurableLanguage::createFromLangcode('ro')->save();
-
-    /** @var \Drupal\Core\Entity\Sql\SqlEntityStorageInterface $storage */
-    $storage = $this->entityTypeManager->getStorage($entity_type_id);
-    $schema_handler = $this->database->schema();
-
-    // Create an entity without the base field, to ensure NULL values are not
-    // added to the dedicated table storage to be purged.
-    /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
-    $entity = $storage->create();
-    $entity->save();
-
-    // Add the base field and run the update.
-    $this->addBaseField('string', $entity_type_id, $base_field_revisionable, TRUE, $create_entity_translation);
-    $this->applyEntityUpdates();
-
-    /** @var \Drupal\Core\Entity\Sql\DefaultTableMapping $table_mapping */
-    $table_mapping = $storage->getTableMapping();
-    $storage_definition = \Drupal::service('entity.last_installed_schema.repository')->getLastInstalledFieldStorageDefinitions($entity_type_id)['new_base_field'];
-
-    // Save an entity with the base field populated.
-    $entity = $storage->create(['new_base_field' => 'foo']);
-    $entity->save();
-
-    if ($create_entity_translation) {
-      $translation = $entity->addTranslation('ro', ['new_base_field' => 'foo-ro']);
-      $translation->save();
-    }
-
-    if ($create_entity_revision) {
-      $entity->setNewRevision(TRUE);
-      $entity->isDefaultRevision(FALSE);
-      $entity->new_base_field = 'bar';
-      $entity->save();
-
-      if ($create_entity_translation) {
-        $translation = $entity->getTranslation('ro');
-        $translation->new_base_field = 'bar-ro';
-        $translation->save();
-      }
-    }
-
-    // Remove the base field and apply updates.
-    $this->removeBaseField($entity_type_id);
-    $this->applyEntityUpdates();
-
-    // Check that the base field's column is deleted.
-    $this->assertFalse($schema_handler->fieldExists($entity_type_id, 'new_base_field'), 'Column deleted from shared table for new_base_field.');
-
-    // Check that a dedicated 'deleted' table was created for the deleted base
-    // field.
-    $dedicated_deleted_table_name = $table_mapping->getDedicatedDataTableName($storage_definition, TRUE);
-    $this->assertTrue($schema_handler->tableExists($dedicated_deleted_table_name), 'A dedicated table was created for the deleted new_base_field.');
-
-    $expected[] = [
-      'bundle' => $entity->bundle(),
-      'deleted' => '1',
-      'entity_id' => '2',
-      'revision_id' => '2',
-      'langcode' => 'en',
-      'delta' => '0',
-      'new_base_field_value' => 'foo',
-    ];
-
-    if ($create_entity_translation) {
-      $expected[] = [
-        'bundle' => $entity->bundle(),
-        'deleted' => '1',
-        'entity_id' => '2',
-        'revision_id' => '2',
-        'langcode' => 'ro',
-        'delta' => '0',
-        'new_base_field_value' => 'foo-ro',
-      ];
-    }
-
-    // Check that the deleted field's data is preserved in the dedicated
-    // 'deleted' table.
-    $result = $this->database->select($dedicated_deleted_table_name, 't')
-      ->fields('t')
-      ->orderBy('revision_id', 'ASC')
-      ->orderBy('langcode', 'ASC')
-      ->execute()
-      ->fetchAll(\PDO::FETCH_ASSOC);
-    $this->assertSameSize($expected, $result);
-
-    // Use assertEquals and not assertSame here to prevent that a different
-    // sequence of the columns in the table will affect the check.
-    $this->assertEquals($expected, $result);
-
-    if ($create_entity_revision) {
-      $dedicated_deleted_revision_table_name = $table_mapping->getDedicatedRevisionTableName($storage_definition, TRUE);
-      $this->assertTrue($schema_handler->tableExists($dedicated_deleted_revision_table_name), 'A dedicated revision table was created for the deleted new_base_field.');
-
-      if ($base_field_revisionable) {
-        $expected[] = [
-          'bundle' => $entity->bundle(),
-          'deleted' => '1',
-          'entity_id' => '2',
-          'revision_id' => '3',
-          'langcode' => 'en',
-          'delta' => '0',
-          'new_base_field_value' => 'bar',
-        ];
-
-        if ($create_entity_translation) {
-          $expected[] = [
-            'bundle' => $entity->bundle(),
-            'deleted' => '1',
-            'entity_id' => '2',
-            'revision_id' => '3',
-            'langcode' => 'ro',
-            'delta' => '0',
-            'new_base_field_value' => 'bar-ro',
-          ];
-        }
-      }
-
-      $result = $this->database->select($dedicated_deleted_revision_table_name, 't')
-        ->fields('t')
-        ->orderBy('revision_id', 'ASC')
-        ->orderBy('langcode', 'ASC')
-        ->execute()
-        ->fetchAll(\PDO::FETCH_ASSOC);
-      $this->assertSameSize($expected, $result);
-
-      // Use assertEquals and not assertSame here to prevent that a different
-      // sequence of the columns in the table will affect the check.
-      $this->assertEquals($expected, $result);
-    }
-
-    // Check that the field storage definition is marked for purging.
-    $deleted_storage_definitions = \Drupal::service('entity_field.deleted_fields_repository')->getFieldStorageDefinitions();
-    $this->assertArrayHasKey($storage_definition->getUniqueStorageIdentifier(), $deleted_storage_definitions, 'The base field is marked for purging.');
-
-    // Purge field data, and check that the storage definition has been
-    // completely removed once the data is purged.
-    field_purge_batch(10);
-    $deleted_storage_definitions = \Drupal::service('entity_field.deleted_fields_repository')->getFieldStorageDefinitions();
-    $this->assertEmpty($deleted_storage_definitions, 'The base field has been deleted.');
-    $this->assertFalse($schema_handler->tableExists($dedicated_deleted_table_name), 'A dedicated field table was deleted after new_base_field was purged.');
-
-    if (isset($dedicated_deleted_revision_table_name)) {
-      $this->assertFalse($schema_handler->tableExists($dedicated_deleted_revision_table_name), 'A dedicated field revision table was deleted after new_base_field was purged.');
-    }
-  }
-
-  /**
-   * Test cases for ::testBaseFieldDeleteWithExistingData.
-   */
-  public function baseFieldDeleteWithExistingDataTestCases() {
-    return [
-      'Non-revisionable, non-translatable entity type' => [
-        'entity_test_update',
-        FALSE,
-        FALSE,
-        FALSE,
-      ],
-      'Non-revisionable, non-translatable custom data table' => [
-        'entity_test_mul',
-        FALSE,
-        FALSE,
-        FALSE,
-      ],
-      'Non-revisionable, non-translatable entity type, revisionable base field' => [
-        'entity_test_update',
-        FALSE,
-        TRUE,
-        FALSE,
-      ],
-      'Non-revisionable, non-translatable custom data table, revisionable base field' => [
-        'entity_test_mul',
-        FALSE,
-        TRUE,
-        FALSE,
-      ],
-      'Revisionable, translatable entity type, non revisionable and non-translatable base field' => [
-        'entity_test_mulrev',
-        TRUE,
-        FALSE,
-        FALSE,
-      ],
-      'Revisionable, translatable entity type, revisionable and non-translatable base field' => [
-        'entity_test_mulrev',
-        TRUE,
-        TRUE,
-        FALSE,
-      ],
-      'Revisionable and non-translatable entity type, revisionable and non-translatable base field' => [
-        'entity_test_rev',
-        TRUE,
-        TRUE,
-        FALSE,
-      ],
-      'Revisionable and non-translatable entity type, non-revisionable and non-translatable base field' => [
-        'entity_test_rev',
-        TRUE,
-        FALSE,
-        FALSE,
-      ],
-      'Revisionable and translatable entity type, non-revisionable and translatable base field' => [
-        'entity_test_mulrev',
-        TRUE,
-        FALSE,
-        TRUE,
-      ],
-      'Revisionable and translatable entity type, revisionable and translatable base field' => [
-        'entity_test_mulrev',
-        TRUE,
-        TRUE,
-        TRUE,
-      ],
-    ];
-  }
-
   /**
    * Tests deleting a bundle field when it has existing data.
    */
-  public function testBundleFieldDeleteWithExistingData() {
+  public function testBundleFieldDeleteWithExistingData(): void {
     /** @var \Drupal\Core\Entity\Sql\SqlEntityStorageInterface $storage */
     $storage = $this->entityTypeManager->getStorage('entity_test_update');
     $schema_handler = $this->database->schema();
@@ -812,7 +589,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
   /**
    * Tests updating a base field when it has existing data.
    */
-  public function testBaseFieldUpdateWithExistingData() {
+  public function testBaseFieldUpdateWithExistingData(): void {
     // Add the base field and run the update.
     $this->addBaseField();
     $this->applyEntityUpdates();
@@ -827,7 +604,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
       $this->applyEntityUpdates();
       $this->fail('FieldStorageDefinitionUpdateForbiddenException thrown when trying to update a field schema that has data.');
     }
-    catch (FieldStorageDefinitionUpdateForbiddenException $e) {
+    catch (FieldStorageDefinitionUpdateForbiddenException) {
       // Expected exception; just continue testing.
     }
   }
@@ -835,7 +612,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
   /**
    * Tests updating a bundle field when it has existing data.
    */
-  public function testBundleFieldUpdateWithExistingData() {
+  public function testBundleFieldUpdateWithExistingData(): void {
     // Add the bundle field and run the update.
     $this->addBundleField();
     $this->applyEntityUpdates();
@@ -851,7 +628,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
       $this->applyEntityUpdates();
       $this->fail('FieldStorageDefinitionUpdateForbiddenException thrown when trying to update a field schema that has data.');
     }
-    catch (FieldStorageDefinitionUpdateForbiddenException $e) {
+    catch (FieldStorageDefinitionUpdateForbiddenException) {
       // Expected exception; just continue testing.
     }
   }
@@ -859,7 +636,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
   /**
    * Tests updating a bundle field when the entity type schema has changed.
    */
-  public function testBundleFieldUpdateWithEntityTypeSchemaUpdate() {
+  public function testBundleFieldUpdateWithEntityTypeSchemaUpdate(): void {
     // Add the bundle field and run the update.
     $this->addBundleField();
     $this->applyEntityUpdates();
@@ -878,7 +655,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
   /**
    * Tests creating and deleting a multi-field index when there are no existing entities.
    */
-  public function testEntityIndexCreateDeleteWithoutData() {
+  public function testEntityIndexCreateDeleteWithoutData(): void {
     // Add an entity index and ensure the update manager reports that as an
     // update to the entity type.
     $this->addEntityIndex();
@@ -932,7 +709,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
   /**
    * Tests creating a multi-field index when there are existing entities.
    */
-  public function testEntityIndexCreateWithData() {
+  public function testEntityIndexCreateWithData(): void {
     // Save an entity.
     $name = $this->randomString();
     $entity = $this->entityTypeManager->getStorage('entity_test_update')->create(['name' => $name]);
@@ -950,7 +727,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
   /**
    * Tests entity type and field storage definition events.
    */
-  public function testDefinitionEvents() {
+  public function testDefinitionEvents(): void {
     /** @var \Drupal\entity_test\EntityTestDefinitionSubscriber $event_subscriber */
     $event_subscriber = $this->container->get('entity_test.definition.subscriber');
     $event_subscriber->enableEventTracking();
@@ -1027,7 +804,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
   /**
    * Tests applying single updates.
    */
-  public function testSingleActionCalls() {
+  public function testSingleActionCalls(): void {
     $db_schema = $this->database->schema();
 
     // Ensure that a non-existing entity type cannot be installed.
@@ -1036,7 +813,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
       $this->entityDefinitionUpdateManager->installEntityType(new ContentEntityType(['id' => 'foo']));
       $this->fail($message);
     }
-    catch (PluginNotFoundException $e) {
+    catch (PluginNotFoundException) {
       // Expected exception; just continue testing.
     }
 
@@ -1049,7 +826,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
       $this->entityDefinitionUpdateManager->installFieldStorageDefinition('bar', 'foo', 'entity_test', $storage_definition);
       $this->fail($message);
     }
-    catch (PluginNotFoundException $e) {
+    catch (PluginNotFoundException) {
       // Expected exception; just continue testing.
     }
 
@@ -1105,7 +882,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
    *
    * @see Drupal\Core\Entity\Sql\SqlContentEntityStorageSchema::createSharedTableSchema
    */
-  public function testCreateFieldAndIndexOnSharedTable() {
+  public function testCreateFieldAndIndexOnSharedTable(): void {
     $this->addBaseField();
     $this->addBaseFieldIndex();
     $this->applyEntityUpdates();
@@ -1123,7 +900,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
    *
    * @see Drupal\Core\Entity\Sql\SqlContentEntityStorageSchema::onEntityTypeUpdate
    */
-  public function testCreateIndexUsingEntityStorageSchemaWithData() {
+  public function testCreateIndexUsingEntityStorageSchemaWithData(): void {
     // Save an entity.
     $name = $this->randomString();
     $storage = $this->entityTypeManager->getStorage('entity_test_update');
@@ -1150,7 +927,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
   /**
    * Tests updating a base field when it has existing data.
    */
-  public function testBaseFieldEntityKeyUpdateWithExistingData() {
+  public function testBaseFieldEntityKeyUpdateWithExistingData(): void {
     // Add the base field and run the update.
     $this->addBaseField();
     $this->applyEntityUpdates();
@@ -1178,7 +955,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
       $this->applyEntityUpdates();
       $this->fail($message);
     }
-    catch (EntityStorageException $e) {
+    catch (EntityStorageException) {
       // Expected exception; just continue testing.
     }
 
@@ -1194,7 +971,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
       $entity->save();
       $this->fail($message);
     }
-    catch (EntityStorageException $e) {
+    catch (EntityStorageException) {
       // Expected exception; just continue testing.
     }
   }
@@ -1202,7 +979,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
   /**
    * Check that field schema is correctly handled with long-named fields.
    */
-  public function testLongNameFieldIndexes() {
+  public function testLongNameFieldIndexes(): void {
     $this->addLongNameBaseField();
     $entity_type_id = 'entity_test_update';
     $entity_type = $this->entityTypeManager->getDefinition($entity_type_id);
@@ -1215,12 +992,11 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
   /**
    * Tests adding a base field with initial values.
    */
-  public function testInitialValue() {
+  public function testInitialValue(): void {
     $storage = \Drupal::entityTypeManager()->getStorage('entity_test_update');
     $db_schema = $this->database->schema();
 
     // Create two entities before adding the base field.
-    /** @var \Drupal\entity_test\Entity\EntityTestUpdate $entity */
     $storage->create()->save();
     $storage->create()->save();
 
@@ -1241,86 +1017,10 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
     $this->assertEquals('test value', $entities[2]->get('new_base_field')->value);
   }
 
-  /**
-   * Tests adding a base field with initial values inherited from another field.
-   *
-   * @dataProvider initialValueFromFieldTestCases
-   */
-  public function testInitialValueFromField($default_initial_value, $expected_value) {
-    $storage = \Drupal::entityTypeManager()->getStorage('entity_test_update');
-    $db_schema = $this->database->schema();
-
-    // Create two entities before adding the base field.
-    /** @var \Drupal\entity_test_update\Entity\EntityTestUpdate $entity */
-    $storage->create([
-      'name' => 'First entity',
-      'test_single_property' => 'test existing value',
-    ])->save();
-
-    // The second entity does not have any value for the 'test_single_property'
-    // field, allowing us to test the 'default_value' parameter of
-    // \Drupal\Core\Field\BaseFieldDefinition::setInitialValueFromField().
-    $storage->create([
-      'name' => 'Second entity',
-    ])->save();
-
-    // Add a base field with an initial value inherited from another field.
-    $definitions['new_base_field'] = BaseFieldDefinition::create('string')
-      ->setName('new_base_field')
-      ->setLabel('A new base field')
-      ->setInitialValueFromField('name');
-    $definitions['another_base_field'] = BaseFieldDefinition::create('string')
-      ->setName('another_base_field')
-      ->setLabel('Another base field')
-      ->setInitialValueFromField('test_single_property', $default_initial_value);
-
-    $this->state->set('entity_test_update.additional_base_field_definitions', $definitions);
-
-    $this->assertFalse($db_schema->fieldExists('entity_test_update', 'new_base_field'), "New field 'new_base_field' does not exist before applying the update.");
-    $this->assertFalse($db_schema->fieldExists('entity_test_update', 'another_base_field'), "New field 'another_base_field' does not exist before applying the update.");
-    $this->entityDefinitionUpdateManager->installFieldStorageDefinition('new_base_field', 'entity_test_update', 'entity_test', $definitions['new_base_field']);
-    $this->entityDefinitionUpdateManager->installFieldStorageDefinition('another_base_field', 'entity_test_update', 'entity_test', $definitions['another_base_field']);
-    $this->assertTrue($db_schema->fieldExists('entity_test_update', 'new_base_field'), "New field 'new_base_field' has been created on the 'entity_test_update' table.");
-    $this->assertTrue($db_schema->fieldExists('entity_test_update', 'another_base_field'), "New field 'another_base_field' has been created on the 'entity_test_update' table.");
-
-    // Check that the initial values have been applied.
-    $storage = \Drupal::entityTypeManager()->getStorage('entity_test_update');
-    $entities = $storage->loadMultiple();
-    $this->assertEquals('First entity', $entities[1]->get('new_base_field')->value);
-    $this->assertEquals('Second entity', $entities[2]->get('new_base_field')->value);
-
-    $this->assertEquals('test existing value', $entities[1]->get('another_base_field')->value);
-    $this->assertEquals($expected_value, $entities[2]->get('another_base_field')->value);
-  }
-
-  /**
-   * Test cases for ::testInitialValueFromField.
-   */
-  public function initialValueFromFieldTestCases() {
-    return [
-      'literal value' => [
-        'test initial value',
-        'test initial value',
-      ],
-      'indexed array' => [
-        ['value' => 'test initial value'],
-        'test initial value',
-      ],
-      'empty array' => [
-        [],
-        NULL,
-      ],
-      'null' => [
-        NULL,
-        NULL,
-      ],
-    ];
-  }
-
   /**
    * Tests the error handling when using initial values from another field.
    */
-  public function testInitialValueFromFieldErrorHandling() {
+  public function testInitialValueFromFieldErrorHandling(): void {
     // Check that setting invalid values for 'initial value from field' doesn't
     // work.
     try {
@@ -1374,7 +1074,7 @@ class EntityDefinitionUpdateTest extends EntityKernelTestBase {
   /**
    * @covers ::getEntityTypes
    */
-  public function testGetEntityTypes() {
+  public function testGetEntityTypes(): void {
     $entity_type_definitions = $this->entityDefinitionUpdateManager->getEntityTypes();
 
     // Ensure that we have at least one entity type to check below.
