@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\KernelTests\Core\Menu;
 
 use Drupal\Component\Plugin\Exception\PluginException;
@@ -7,6 +9,8 @@ use Drupal\Core\Menu\MenuTreeParameters;
 use Drupal\Core\Menu\MenuTreeStorage;
 use Drupal\KernelTests\KernelTestBase;
 
+// cspell:ignore mlid
+
 /**
  * Tests the menu tree storage.
  *
@@ -43,7 +47,7 @@ class MenuTreeStorageTest extends KernelTestBase {
   /**
    * Tests the tree storage when no tree was built yet.
    */
-  public function testBasicMethods() {
+  public function testBasicMethods(): void {
     $this->doTestEmptyStorage();
     $this->doTestTable();
   }
@@ -51,14 +55,14 @@ class MenuTreeStorageTest extends KernelTestBase {
   /**
    * Ensures that there are no menu links by default.
    */
-  protected function doTestEmptyStorage() {
+  protected function doTestEmptyStorage(): void {
     $this->assertEquals(0, $this->treeStorage->countMenuLinks());
   }
 
   /**
    * Ensures that table gets created on the fly.
    */
-  protected function doTestTable() {
+  protected function doTestTable(): void {
     // Test that we can create a tree storage with an arbitrary table name and
     // that selecting from the storage creates the table.
     $tree_storage = new MenuTreeStorage($this->container->get('database'), $this->container->get('cache.menu'), $this->container->get('cache_tags.invalidator'), 'test_menu_tree');
@@ -70,7 +74,7 @@ class MenuTreeStorageTest extends KernelTestBase {
   /**
    * Tests with a simple linear hierarchy.
    */
-  public function testSimpleHierarchy() {
+  public function testSimpleHierarchy(): void {
     // Add some links with parent on the previous one and test some values.
     // <tools>
     // - test1
@@ -92,7 +96,7 @@ class MenuTreeStorageTest extends KernelTestBase {
   /**
    * Tests the tree with moving links inside the hierarchy.
    */
-  public function testMenuLinkMoving() {
+  public function testMenuLinkMoving(): void {
     // Before the move.
     // <tools>
     // - test1
@@ -170,7 +174,7 @@ class MenuTreeStorageTest extends KernelTestBase {
   /**
    * Tests with disabled child links.
    */
-  public function testMenuDisabledChildLinks() {
+  public function testMenuDisabledChildLinks(): void {
     // Add some links with parent on the previous one and test some values.
     // <tools>
     // - test1
@@ -213,7 +217,7 @@ class MenuTreeStorageTest extends KernelTestBase {
       $this->moveMenuLink('test1', 'footerA');
       $this->fail('Exception was not thrown');
     }
-    catch (PluginException $e) {
+    catch (PluginException) {
       // Expected exception; just continue testing.
     }
     // The opposite move should work, and change the has_children flag.
@@ -225,7 +229,7 @@ class MenuTreeStorageTest extends KernelTestBase {
   /**
    * Tests the loadTreeData method.
    */
-  public function testLoadTree() {
+  public function testLoadTree(): void {
     $this->addMenuLink('test1', '', 'test1');
     $this->addMenuLink('test2', 'test1', 'test2');
     $this->addMenuLink('test3', 'test2', 'test3');
@@ -295,7 +299,7 @@ class MenuTreeStorageTest extends KernelTestBase {
   /**
    * Tests finding the subtree height with content menu links.
    */
-  public function testSubtreeHeight() {
+  public function testSubtreeHeight(): void {
     // root
     // - child1
     // -- child2
@@ -317,7 +321,7 @@ class MenuTreeStorageTest extends KernelTestBase {
   /**
    * Ensure hierarchy persists after a menu rebuild.
    */
-  public function testMenuRebuild() {
+  public function testMenuRebuild(): void {
     // root
     // - child1
     // -- child2
@@ -348,7 +352,7 @@ class MenuTreeStorageTest extends KernelTestBase {
   /**
    * Tests MenuTreeStorage::loadByProperties().
    */
-  public function testLoadByProperties() {
+  public function testLoadByProperties(): void {
     $tests = [
       ['foo' => 'bar'],
       [0 => 'wrong'],
@@ -373,7 +377,7 @@ class MenuTreeStorageTest extends KernelTestBase {
   /**
    * Adds a link with the given ID and supply defaults.
    */
-  protected function addMenuLink($id, $parent = '', $route_name = 'test', $route_parameters = [], $menu_name = 'tools', $extra = []) {
+  protected function addMenuLink($id, $parent = '', $route_name = 'test', $route_parameters = [], $menu_name = 'tools', $extra = []): void {
     $link = [
       'id' => $id,
       'menu_name' => $menu_name,
@@ -395,7 +399,7 @@ class MenuTreeStorageTest extends KernelTestBase {
    * @param string $new_parent
    *   The ID of the new parent link.
    */
-  protected function moveMenuLink($id, $new_parent) {
+  protected function moveMenuLink($id, $new_parent): void {
     $menu_link = $this->treeStorage->load($id);
     $menu_link['parent'] = $new_parent;
     $this->treeStorage->save($menu_link);
