@@ -4,13 +4,10 @@ declare(strict_types=1);
 
 namespace Drupal\Tests\Composer\Plugin\Scaffold;
 
-use Drupal\Tests\Traits\PhpUnitWarnings;
-
 /**
  * Convenience class for creating fixtures.
  */
 trait AssertUtilsTrait {
-  use PhpUnitWarnings;
 
   /**
    * Asserts that a given file exists and is/is not a symlink.
